Class: WillPaginate::ViewHelpers::LinkRenderer
- Inherits:
-
LinkRendererBase
- Object
- LinkRendererBase
- WillPaginate::ViewHelpers::LinkRenderer
- Defined in:
- lib/will_paginate/view_helpers/link_renderer.rb
Overview
This class does the heavy lifting of actually building the pagination
links. It is used by will_paginate helper internally.
Direct Known Subclasses
ActionView::LinkRenderer, Hanami::LinkRenderer, Sinatra::LinkRenderer
Instance Method Summary collapse
-
#container_attributes ⇒ Object
Returns the subset of
optionsthis instance was initialized with that represent HTML attributes for the container element of pagination links. -
#prepare(collection, options, template) ⇒ Object
collectionis a WillPaginate::Collection instance or any other object that conforms to that API *optionsare forwarded fromwill_paginateview helper *templateis the reference to the template being rendered.
-
#to_html ⇒ Object
Process it! This method returns the complete HTML string which contains pagination links.
Methods inherited from LinkRendererBase
Instance Method Details
#container_attributes ⇒ Object
Returns the subset of options this instance was initialized with that
represent HTML attributes for the container element of pagination links.
37 38 39 40 41 42 |
# File 'lib/will_paginate/view_helpers/link_renderer.rb', line 37 def container_attributes @container_attributes ||= { :role => 'navigation', :"aria-label" => @template.will_paginate_translate(:container_aria_label) { 'Pagination' } }.update @options.except(*(ViewHelpers..keys + [:renderer] - [:class])) end |
#prepare(collection, options, template) ⇒ Object
collectionis a WillPaginate::Collection instance or any other object that conforms to that APIoptionsare forwarded fromwill_paginateview helpertemplateis the reference to the template being rendered
16 17 18 19 20 |
# File 'lib/will_paginate/view_helpers/link_renderer.rb', line 16 def prepare(collection, , template) super(collection, ) @template = template @container_attributes = @base_url_params = nil end |
#to_html ⇒ Object
Process it! This method returns the complete HTML string which contains pagination links. Feel free to subclass LinkRenderer and change this method as you see fit.
25 26 27 28 29 30 31 32 33 |
# File 'lib/will_paginate/view_helpers/link_renderer.rb', line 25 def to_html html = pagination.map do |item| item.is_a?(Integer) ? page_number(item) : send(item) end.join(@options[:link_separator]) @options[:container] ? html_container(html) : html end |